@@ -322,33 +322,36 @@ class R3sponse(object):
 				self.assign(attributes)
 
 			# clean message & error.
-			if self.message != None:
-				self.message = Formats.String(self.message).capitalized_word()
-			if self.error != None:
-				self.error = Formats.String(self.error).capitalized_word()
-			while True:
-				if self.message != None and len(self.message) >= 1 and self.message[len(self.message)-1] in [" ", ".", ","]:
-					self.message = self.message[:-1]
-				elif self.error != None and len(self.error) >= 1 and self.error[len(self.error)-1] in [" ", ".", ","]:
-					self.error = self.error[:-1]
-				elif self.error != None and len(self.error) >= len("Error: ") and self.error[:len("Error: ")] in ["Error: "]:
-					self.error = Formats.String(self.error[len("Error: "):]).capitalized_word()
-				else: break
-			
-			# add dot.
-			if self.message != None  and len(self.message) > 0 and self.message[len(self.message)-1] not in ["!", "?"]:
-				self.message += "."
-			if self.error != None  and len(self.error) > 0 and self.error[len(self.error)-1] not in ["!", "?"]:
-				self.error += "."
+			try:
+				if self.message != None:
+					self.message = Formats.String(self.message).capitalized_word()
+				if self.error != None:
+					self.error = Formats.String(self.error).capitalized_word()
+				while True:
+					if self.message != None and len(self.message) >= 1 and self.message[len(self.message)-1] in [" ", ".", ","]:
+						self.message = self.message[:-1]
+					elif self.error != None and len(self.error) >= 1 and self.error[len(self.error)-1] in [" ", ".", ","]:
+						self.error = self.error[:-1]
+					elif self.error != None and len(self.error) >= len("Error: ") and self.error[:len("Error: ")] in ["Error: "]:
+						self.error = Formats.String(self.error[len("Error: "):]).capitalized_word()
+					else: break
+				
+				# add dot.
+				if self.message != None  and len(self.message) > 0 and self.message[len(self.message)-1] not in ["!", "?"]:
+					self.message += "."
+				if self.error != None  and len(self.error) > 0 and self.error[len(self.error)-1] not in ["!", "?"]:
+					self.error += "."
 
-			# check error passed as success response. & reversed
-			if self.message != None and len(self.message) >= len("Failed") and self.message[:len("Failed")] == "Failed":
-				#_traceback_.print_exc() 
-				raise ValueError("The first x characters of a success response may not be [Failed].")
-			if self.error != None and len(self.error) >= len("Success") and self.error[:len("Success")] == "Success":
-				#_traceback_.print_exc() 
-				raise ValueError("The first x characters of an error response may not be [Success].")
-			#quit()
+				# check error passed as success response. & reversed
+				if self.message != None and len(self.message) >= len("Failed") and self.message[:len("Failed")] == "Failed":
+					#_traceback_.print_exc() 
+					raise ValueError("A success response may not start with (failed ...). You most likely called an r3sponse.success return while you meant r3sponse.error.")
+				if self.error != None and len(self.error) >= len("Success") and self.error[:len("Success")] == "Success":
+					#_traceback_.print_exc() 
+					raise ValueError("An error response may not start with (success ...). You most likely called an r3sponse.error return while you meant r3sponse.success.")
+			
+			# except if not present.
+			except AttributeError: a=1
 
 		# iterate over self keys & variables.
 		def items(self):
